timeintervaltools.calculate_depth_centroid_of_intervals_in_interval
===================================================================

.. autofunction:: abjad.tools.timeintervaltools.calculate_depth_centroid_of_intervals_in_interval.calculate_depth_centroid_of_intervals_in_interval
